@@ -16,5 +16,5 @@ async fn main() {
             host == "localhost:7878"
         })
         .get(hello_world);
-    Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).serve(router).await;
+    Server::new(TcpListener::bind("0.0.0.0:7878")).serve(router).await;
 }
