@@ -26,5 +26,5 @@ async fn main() {
     let router = Router::new()
         .push(Router::with_path("anyhow").get(handle_anyhow))
         .push(Router::with_path("custom").get(handle_custom));
-    Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).serve(router).await;
+    Server::new(TcpListener::bind("0.0.0.0:7878")).serve(router).await;
 }
