@@ -10,6 +10,6 @@ async fn main() {
     tracing_subscriber::fmt().init();
 
     let router = Router::new().get(hello_world);
-    let listener = TcpListener::bind(([0, 0, 0, 0], 7878)).join(TcpListener::bind(([0, 0, 0, 0], 7979)));
+    let listener = TcpListener::bind("0.0.0.0:7878").join(TcpListener::bind(([0, 0, 0, 0], 7979)));
     Server::new(listener).serve(router).await;
 }
