@@ -33,7 +33,7 @@ async fn main() {
             }
         });
 
-    Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).serve(router).await;
+    Server::new(TcpListener::bind("0.0.0.0:7878")).serve(router).await;
 }
 
 #[fn_handler]
