@@ -40,7 +40,7 @@ async fn main() {
                 .post(upload),
         )
         .push(Router::with_path("unlimit").post(upload));
-    Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).serve(router).await;
+    Server::new(TcpListener::bind("0.0.0.0:7878")).serve(router).await;
 }
 
 static INDEX_HTML: &str = r#"<!DOCTYPE html>
