@@ -36,5 +36,5 @@ async fn main() {
     tracing_subscriber::fmt().init();
 
     let router = Router::with_path("ticks").get(handle_tick);
-    Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).serve(router).await;
+    Server::new(TcpListener::bind("0.0.0.0:7878")).serve(router).await;
 }
