@@ -19,7 +19,7 @@ async fn main() {
             tokio::time::sleep(Duration::from_secs(60)).await;
         }
     })
-    .bind(([0, 0, 0, 0], 7878));
+    .bind("0.0.0.0:7878");
     Server::new(listener).serve(router).await;
 }
 
