@@ -25,7 +25,7 @@ async fn main() {
     let router = Router::new()
         .handle(index)
         .push(Router::with_path("chat").handle(user_connected));
-    Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).serve(router).await;
+    Server::new(TcpListener::bind("0.0.0.0:7878")).serve(router).await;
 }
 
 #[fn_handler]
